# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.19.3](https://github.com/mamba-org/rattler/compare/rattler_digest-v0.19.2...rattler_digest-v0.19.3) - 2024-04-19

### Other
- update Cargo.toml dependencies

## [0.19.2](https://github.com/mamba-org/rattler/compare/rattler_digest-v0.19.1...rattler_digest-v0.19.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/mamba-org/rattler/pull/563))

## [0.19.1](https://github.com/mamba-org/rattler/compare/rattler_digest-v0.19.0...rattler_digest-v0.19.1) - 2024-03-06

### Other
- every crate should have its own version ([#557](https://github.com/mamba-org/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_digest-v0.18.0...rattler_digest-v0.19.0) - 2024-02-26
